import pandas as pd
import numpy as np
import pystan
import matplotlib.pyplot as plt
import seaborn as sb

finnm = input('入力データファイル（*.xlsx） = ')
foutnm = input('画像保存ファイル（*.png）= ')

savedfiles = []         #   保存ファイル名のリスト

#
#       Excelファイルの読み込み
#
xlsx_fl = pd.ExcelFile(finnm)
data_xlsx = pd.read_excel(xlsx_fl,  header = None)
data = data_xlsx.values

VarName = data[0,1]
X = data[1:, 1]
X = list(X)
print(X)

DataStan = {'N': len(X), 'X': X}

sm = pystan.StanModel(file = 'OneVarNormal.stan')
fit = sm.sampling(data = DataStan, n_jobs = 1)
print(fit)

mu_025, mu_50, mu_975 = np.percentile(fit['mu'], [2.5, 50, 97.5])

#       日本語表記の設定
plt.rcParams['font.family'] = ['Yu Gothic', 'Noto Sans CJK JP', 'Hiragino Maru Gothic Pro']

plt.title('平均値の事後分布' + \
          '\nMed = {0:.2f},  95%CI = [{1:.2f}, {2:.2f}]'.format(
              mu_50, mu_025, mu_975), fontsize = 20)
sb.kdeplot(fit['mu'])
plt.xlabel(VarName + 'の平均値', fontsize = 16)
plt.yticks([])
plt.tight_layout()
plt.savefig(foutnm[:-4] + '.png')
savedfiles.append(foutnm[:-4] + '.png')
plt.show()

sgm_025, sgm_50, sgm_975 = np.percentile(fit['sgm'], [2.5, 50, 97.5])
plt.title('標準偏差の事後分布' + \
          '\nMed = {0:.2f},   95%CI = [{1:.2f}, {2:.2f}]'.format(
              sgm_50, sgm_025, sgm_975), fontsize = 20)
sb.kdeplot(fit['sgm'])
plt.xlabel(VarName + 'の標準偏差', fontsize = 14)
plt.yticks([])
plt.tight_layout()
plt.savefig(foutnm[:-4] + '_sgm.png')
savedfiles.append(foutnm[:-4] + '_sgm.png')
plt.show()

print('保存ファイル：')
for v in savedfiles:
    print(v)
